# Backup des bases de données des services

Cet outil orchestre le backup des différents services de Picasoft.

Il est capable de gérer les bases de données `postgres`, `mysql` ou `mongo` pour le moment.

Il est flexible et se configure via des fichiers JSON.

<!-- TOC depthFrom:2 depthTo:6 withLinks:1 updateOnSave:1 orderedList:0 -->

- [Lancement](#lancement)
- [Configuration](#configuration)
	- [Structure](#structure)
	- [Gestion des secrets](#gestion-des-secrets)
	- [Exemple](#exemple)

<!-- /TOC -->

## Lancement

On se synchronise simplement avec le dépôt et on lance le Docker Compose.

On copie `secrets/db.secrets.example` dans `secrets/db.secrets` :
* On assigne le nom de la VM à `HOSTNAME` (*e.g.* `pica02`),
* On renseigne les secrets (voir [plus bas]((#gestion-des-secrets)))

L'outil sélectionne automatiquement le bon fichier de configuration en fonction du nom d'hôte de la machine virtuelle, il n'y a donc rien à modifier :

```
$ docker-compose up -d
```

## Configuration

Les fichiers dans [`.config`](./config) recensent les informations sur les différents services mis en place sur les machines et les informations nécessaires pour lancer les rotations sur ces services.

Ces fichiers **sont** les fichiers utilisés **en production**.
Ils ne doivent pas être modifiés sur les machines sans être synchronisés avec le dépôt Git.

On veillera à ce que les noms d'hôte correspondent bien aux noms des conteneurs (gérés par d'autres Docker Compose), et que le dossier `/DATA/BACKUP` existe.

### Structure

 - Nom du service : Contient une structure de données contenant les informations relatives au service telles qu'indiquées ci-dessous
 - "Host" : Indique l'hôte de la base de données
 - "Port" : Indique le port pour se connecter au service
 - "Database" : Indique le nom de la base de données
 - "User" : Nom d'utilisateur ou nom d'une variable d'environnement (optionnel)
 - "Password" : Mot de passe ou nom d'une variable d'environnement (optionnel)
 - "Folder" : Indique le nom du dossier de backup utilisé par le script de backup et de rotation
 - "Cron" : Indique la fréquence de temps à laquelle les backups sont effectués par le script de rotation au format cron
 - "Init-Backup" : Indique si un backup doit être effectué au démarrage du service, en plus de la programmation du cron
 - "Backup-Rota" : Contient les paramètres pour la rotation des backups dans une structure de données comme indiqué ci-dessous
     - "Hour" : nombre de backups horaires à conserver
     - "Day" : nombre de backups quotidiens à conserver
     - "Week" : nombre de backups hebdomadaires à conserver
     - "Month": nombre de backups mensuels à conserver

### Gestion des secrets

Afin de pouvoir versionner les fichiers de configuration sans exposer les identifiants aux bases de données, on utilise le système suivant :
* Dans le JSON, on utilise un nom de variable d'environnement à la place de l'identifant, **sans le $**, *e.g.* `ETHERPAD_DB_USER`.
* Dans le fichier `db.secrets`, on renseigne la valeur de cette variable d'environnement.

La substitution est effectué automatiquement par l'outil.


### Exemple

```json
{
  "wekan":
    {
      "Host": "wekan-db",
      "Port": "27017",
      "Database": "wekan",
      "Type": "mongo",
      "Folder": "wekan",
      "Cron" : "0 * * * *",
      "Init-Backup" : "0",
      "Backup-Rota":
          {
              "Hour" : 24,
              "Day" : 7,
              "Week" : 4,
              "Month" : 12
          }
    },
  "etherpad":
    {
      "Host": "etherpad-db",
      "Port": "3306",
      "User": "ETHERPAD_DB_USER",
      "Password": "ETHERPAD_DB_PASSWORD",
      "Database": "--all-databases",
      "Type": "mysql",
      "Folder": "etherpad",
      "Cron" : "0 * * * *",
      "Options" : "--single-transaction",
      "Init-Backup" : "0",
      "Backup-Rota":
          {
              "Hour" : 24,
              "Day" : 7,
              "Week" : 4,
              "Month" : 12
          }
    }
}
```
